@@ -46,13 +46,15 @@ gint dbus_req_handler (const gchar *interface, const gchar *method,
         GArray *arguments, gpointer data, osso_rpc_t *retval);
 void exit_event_handler (gboolean die_now, gpointer data);
 
-gchar *app_file_chooser (Application *app, GtkFileChooserAction act) {
+gchar *app_file_chooser (Application *app, const char *title, GtkFileChooserAction act) {
     GtkWidget *dialog;
     gchar *filename = NULL;
     dialog = hildon_file_chooser_dialog_new (app->window, act);
     if (app->save_folder)
         gtk_file_chooser_set_current_folder (
                 GTK_FILE_CHOOSER (dialog), app->save_folder);
+    if (title)
+        gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), title);
     gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
     gtk_widget_show_all (GTK_WIDGET (dialog));
     if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
@@ -190,7 +192,7 @@ void app_normal_screen (Application *app) {
 
 static void callback_file_open (GtkButton * button, Application * app) {
     gchar *filename = NULL;
-    filename = app_file_chooser(app, GTK_FILE_CHOOSER_ACTION_OPEN);
+    filename = app_file_chooser(app, NULL, GTK_FILE_CHOOSER_ACTION_OPEN);
     if (filename) {
         app_open_location (filename, app);
         g_free (filename);
@@ -210,7 +212,7 @@ static void callback_file_go (GtkButton *button, Application *app) {
 
 static void callback_file_save_as (GtkButton * button, Application * app) {
     gchar *filename = NULL;
-    filename = app_file_chooser (app, GTK_FILE_CHOOSER_ACTION_SAVE);
+    filename = app_file_chooser (app, NULL, GTK_FILE_CHOOSER_ACTION_SAVE);
     if (filename) {
         gchar * info;
         if (saveFile (app->control, filename)) {
