@@ -142,7 +142,7 @@ void app_set_suspend (Application *app, bool suspend) MAEMO_NO_EXPORT;
 void app_set_info_content (Application *app, const char * utf8, bool plaintext) MAEMO_NO_EXPORT;
 void app_set_playing (Application *app, int) MAEMO_NO_EXPORT;
 void app_set_title (const char *title, Application *app) MAEMO_NO_EXPORT;
-gchar *app_file_chooser (Application *app, GtkFileChooserAction act);
+gchar *app_file_chooser (Application *app, const char *title, GtkFileChooserAction act);
 
 void openFile (Application *app, const gchar *path) MAEMO_NO_EXPORT;
 const char *saveFile (void *ctr, const gchar *path) MAEMO_NO_EXPORT;
