@@ -68,7 +68,7 @@ void FileDocument::writeToFile (const String & fn) {
 KDE_NO_CDTOR_EXPORT Recents::Recents (Application *a)
     : FileDocument (id_node_recent_document, "recents://"),
       app(a) {
-    pretty_name = "Most Recent";
+    caption = "Most Recent";
 }
 
 KDE_NO_EXPORT void Recents::activate () {
@@ -119,8 +119,8 @@ KDE_NO_EXPORT void Recent::activate () {
 
 KDE_NO_CDTOR_EXPORT
 Group::Group (KMPlayer::NodePtr & doc, Application * a, const String & pn)
-  : KMPlayer::Mrl (doc, KMPlayer::id_node_group_node), app (a) {
-    pretty_name = pn;
+  : KMPlayer::Element (doc, KMPlayer::id_node_group_node), app (a) {
+    caption = pn;
     if (!pn.isEmpty ())
         setAttribute (KMPlayer::StringPool::attr_title, pn);
 }
@@ -134,8 +134,8 @@ KDE_NO_EXPORT KMPlayer::Node *Group::childFromTag (const String & tag) {
 }
 
 KDE_NO_EXPORT void Group::closed () {
-    if (pretty_name.isEmpty ())
-        pretty_name = getAttribute (KMPlayer::StringPool::attr_title);
+    if (caption.isEmpty ())
+        caption = getAttribute (KMPlayer::StringPool::attr_title);
 }
 
 // gconftool -s -t string /apps/maemo/kmplayer/playlist_file /home/koos/playlist.xml
@@ -159,7 +159,7 @@ KDE_NO_CDTOR_EXPORT Playlist::Playlist (Application *a, KMPlayer::Control *s, bo
     : FileDocument (KMPlayer::id_node_playlist_document, "Playlist://", s),
       app(a),
       playmode (plmode) {
-    pretty_name = "Persistent Playlists";
+    caption = "Persistent Playlists";
 }
 
 KDE_NO_EXPORT KMPlayer::Node *Playlist::childFromTag (const String & tag) {
@@ -197,12 +197,12 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
         if (parentNode ()->id == KMPlayer::id_node_group_node &&
                 (previousSibling() || nextSibling ())) {
             data = parentNode ()->innerXML ();
-            pn = parentNode ()->mrl ()->pretty_name;
+            pn = parentNode ()->caption;
         } else {
             data = outerXML ();
-            pn = pretty_name.isEmpty () ? src : pretty_name;
+            pn = caption.isEmpty () ? src : caption;
         }
-        pl->mrl ()->pretty_name = pn;
+        pl->caption = pn;
         //debugLog () << "cloning to " << data << endl;
         TextStream inxml (data);
         KMPlayer::readXML (pl, inxml, String(), false);
@@ -221,8 +221,8 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
 }
 
 KDE_NO_EXPORT void PlaylistItemBase::closed () {
-    if (pretty_name.isEmpty ())
-        pretty_name = getAttribute (KMPlayer::StringPool::attr_title);
+    if (caption.isEmpty ())
+        caption = getAttribute (KMPlayer::StringPool::attr_title);
 }
 
 KDE_NO_CDTOR_EXPORT
@@ -253,7 +253,7 @@ KDE_NO_EXPORT void PlaylistItem::setNodeName (const String & s) {
 KDE_NO_CDTOR_EXPORT
 PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, const String & pn)
   : KMPlayer::Mrl (doc, KMPlayer::id_node_group_node), app (a), playmode (false) {
-    pretty_name = pn;
+    caption = pn;
     if (!pn.isEmpty ())
         setAttribute (KMPlayer::StringPool::attr_title, pn);
 }
@@ -275,12 +275,12 @@ KDE_NO_EXPORT KMPlayer::Node *PlaylistGroup::childFromTag (const String & tag) {
 }
 
 KDE_NO_EXPORT void PlaylistGroup::closed () {
-    if (pretty_name.isEmpty ())
-        pretty_name = getAttribute (KMPlayer::StringPool::attr_title);
+    if (caption.isEmpty ())
+        caption = getAttribute (KMPlayer::StringPool::attr_title);
 }
 
 KDE_NO_EXPORT void PlaylistGroup::setNodeName (const String & t) {
-    pretty_name = t;
+    caption = t;
     setAttribute (KMPlayer::StringPool::attr_title, t);
 }
 
