@@ -75,11 +75,10 @@ public:
     Application * app;
 };
 
-class KMPLAYER_NO_EXPORT Group : public KMPlayer::Mrl {
+class KMPLAYER_NO_EXPORT Group : public KMPlayer::Element {
 public:
     Group (KMPlayer::NodePtr &doc, Application *a, const String &pn=String());
     KMPlayer::Node *childFromTag (const String & tag);
-    void defer () {} // TODO lazy loading of largish sub trees
     void closed ();
     KDE_NO_EXPORT const char * nodeName () const { return "group"; }
     Application * app;
