@@ -40,13 +40,13 @@ KMPLAYER_NO_EXPORT Node *RSS::Channel::childFromTag (const String & tag) {
 KMPLAYER_NO_EXPORT void RSS::Channel::closed () {
     for (NodePtr c = firstChild (); c; c = c->nextSibling ())
         if (c->id == id_node_title) {
-            pretty_name = c->innerText ().stripWhiteSpace ();
+            caption = c->innerText ().stripWhiteSpace ();
             break;
         }
 }
 
 KMPLAYER_NO_EXPORT bool RSS::Channel::expose () const {
-    return !pretty_name.isEmpty () || //return false if no title and only one
+    return !caption.isEmpty () || //return false if no caption and only one
         previousSibling () || nextSibling ();
 }
 
@@ -66,7 +66,7 @@ KMPLAYER_NO_EXPORT void RSS::Item::closed () {
     for (NodePtr c = firstChild (); c; c = c->nextSibling ()) {
         switch (c->id) {
             case id_node_title:
-                pretty_name = c->innerText ().stripWhiteSpace ();
+                caption = c->innerText ().stripWhiteSpace ();
                 break;
             case id_node_enclosure:
                 enclosure = c;
@@ -77,8 +77,10 @@ KMPLAYER_NO_EXPORT void RSS::Item::closed () {
                 break;
         }
     }
-    if (enclosure && !enclosure->mrl ()->src.isEmpty ())
+    if (enclosure && !enclosure->mrl ()->src.isEmpty ()) {
         cached_play_type = play_type_audio;
+        enclosure->caption = caption;
+    }
 }
 
 KMPLAYER_NO_EXPORT Mrl * RSS::Item::linkNode () {
