@@ -1135,7 +1135,8 @@ void KMPlayer::jump (Node *n, Control *ctr) {
                 ctr->playlist_data->document->defer ();   // pause
         } else {
             //debugLog() << "jump " << mrl->src << endl;
-            ctr->back_request = mrl;
+            // FIXME: group activation doesn't work
+            ctr->back_request = id_node_group_node == n->id ? mrl : n;
             if (ctr->process ()->playing ())
                 ctr->process ()->stop ();
             else
