@@ -43,6 +43,8 @@ struct MAEMO_NO_EXPORT PlayListData {
     NodePtr document;
     NodePtrW current;
     GdkPixbuf * icon;
+    Document *updated_document;
+    unsigned int updated_document_version;
     short id;
     bool show_all;
     bool edit_mode;
@@ -90,8 +92,6 @@ public:
     bool setCurrent (NodePtr);
     bool applyBackRequest();
     void stateElementChanged (Node * n, Node::State os, Node::State ns);
-    Surface *getSurface (Mrl *mrl);
-    void setInfoMessage (const String & msg);
     void updateViewAreaSizes ();
     void bitRates (int & prefered, int & maximal);
     void setTimeout (int ms);
@@ -109,7 +109,6 @@ public:
     // ProcessNotify
     void stateChanged (Process * p, Process::State os, Process::State ns);
     void errorMsg (const String & msg);
-    void infoMsg (const String & msg);
     void setLoading (int perc);
     void setPosition (int pos) ;
     void setLength (int len);
@@ -146,6 +145,16 @@ private:
     virtual void jobData (Job * job, ByteArray & data);
     virtual void jobResult (Job * job);
     ActorAgent *actor_agent;
+    NodeList extra_playlists;
+};
+
+class MAEMO_NO_EXPORT SourceDocument : public Document {
+public:
+    SourceDocument (Control *c, const String &url);
+
+    void *message (MessageType msg, void *data=NULL);
+
+    Control *m_control;
 };
 
 void updateTree (Application *app, short id) MAEMO_NO_EXPORT;
