@@ -441,6 +441,7 @@ protected:
     Node (NodePtr & d, short _id=0);
     NodePtr m_doc;
 public:
+    String caption;
     State state;
     short id;
 private:
@@ -548,7 +549,6 @@ public:
     NodePtrW opener; //if this node is top node of external document,
     Actor *actor;
     String src;
-    String pretty_name;
     String mimetype;
     Single width;
     Single height;
