@@ -113,15 +113,14 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
     else
         iter = *riter;
     Mrl *mrl = e->mrl ();
-    String text (e->nodeName());
+    String text(e->caption.isEmpty() ? e->nodeName() : (const char*)e->caption);
     if (mrl && !pld->show_all) {
-        if (mrl->pretty_name.isEmpty ()) {
+        if (mrl->caption.isEmpty ()) {
             if (!mrl->src.isEmpty())
                 text = mrl->src; // URL(mrl->src).url (); //prettyURL();
             else if (e->isDocument ())
                 text = e->hasChildNodes () ? "unnamed" : "None";
-        } else
-            text = mrl->pretty_name;
+        }
     } else if (e->id == id_node_text) {
         String txt (e->nodeValue ());
         int pos = txt.indexOf (Char ('\n'));
@@ -478,7 +477,6 @@ void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
     GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
     GtkTreeIter iter;
     PlayListData * pld = 0L;
-    NodePtr node;
     debugLog() << "tree selection changed" << endl;
     //g_print ("cb_selection_changed %d\n", app->playlist_data->show_all);
     if (gtk_tree_selection_get_selected (selection, 0L, &iter)) {
@@ -487,11 +485,11 @@ void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
         restoreEditMode (app, pld);
         GtkTreePath* path = gtk_tree_model_get_path (model, &iter);
         gtk_tree_view_scroll_to_cell (treeview, path, NULL, false, 0, 0);
-        node = getNode (pld, path);
+        NodePtr node = getNode (pld, path);
+        Mrl *mrl = node ? node->mrl () : NULL;
         gtk_tree_path_free (path);
-        if (pld->id > 0 && node &&
-                node == pld->document && !node->mrl ()->resolved) {
-            node->activate ();
+        if (mrl && pld->id > 0 && node == pld->document && !mrl->resolved) {
+            mrl->activate ();
             if (!node->isPlayable ()) // lazy playlist/recents loading
                 updateTree (app, pld->id);
         } else {
@@ -500,7 +498,7 @@ void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
                     : "", pld->edit_mode);
         }
         CONTROL(app)->setCurrentSelected (node);
-        if (pld->id > 0) //FIXME, hack to become less jumpy when changing trees
+        if (mrl && pld->id > 0) //FIXME, hack to become less jumpy when changing trees
             pld->current = node;
     }
 }
@@ -516,7 +514,7 @@ void cb_row_activated (GtkTreeView * tree_view, GtkTreePath *path,
         app_set_info_content (app, node
                 ? (pld->edit_mode ? node->innerXML () : node->innerText ())
                 : "", pld->edit_mode);
-    if (!pld->edit_mode)
+    if (!pld->edit_mode && (pld->id == 0 || node->mrl ()))
         jump (node.ptr (), CONTROL(app));
 }
 
@@ -530,7 +528,7 @@ void KMPlayer::rowSelected (Application * app) {
     app_set_info_content (app, node
             ? (pld->edit_mode ? node->innerXML () : node->innerText ())
             : "", pld->edit_mode);
-    if (!pld->edit_mode)
+    if (!pld->edit_mode && (pld->id == 0 || node->mrl ()))
         jump (node.ptr (), CONTROL(app));
 }
 
@@ -627,8 +625,8 @@ short KMPlayer::addTree (Application * app, NodePtr doc, GdkPixbuf * ico) {
     (*prev)->document = doc;
     (*prev)->icon = ico;
     const char * title = "empty";
-    if (doc && !doc->mrl()->pretty_name.isEmpty())
-        title = (const char *) doc->mrl()->pretty_name;
+    if (doc && !doc->caption.isEmpty())
+        title = (const char *) doc->caption;
     GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (app->playlist_view));
     gtk_tree_store_append (GTK_TREE_STORE (model), &iter, 0L);
     gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
