@@ -1597,7 +1597,31 @@ bool KMPLAYER_NO_EXPORT Downloader::play (NodePtr mrl) {
     saved_file.clear ();
     if (!m_url.isEmpty ()) {
         gchar *filename = NULL;
-        filename = app_file_chooser (application, GTK_FILE_CHOOSER_ACTION_SAVE);
+        String name = mrl->caption;
+        if (!name.isEmpty ()) {
+            name = "";
+            for (const char *s = (const char *)mrl->caption; s && *s; ++s)
+                switch (*s) {
+                    case '\n':
+                    case ';':
+                    case ':':
+                    case '*':
+                    case '?':
+                    case ',':
+                    case '&':
+                    case '>':
+                    case '<':
+                    case '|':
+                    case '"':
+                    case '\'':
+                        break;
+                    default:
+                        name += Char (*s);
+                }
+        }
+        filename = app_file_chooser (application,
+                (name.isEmpty () ? NULL : (const char *) name),
+                GTK_FILE_CHOOSER_ACTION_SAVE);
         if (filename) {
             fd = open (filename, O_WRONLY | O_CREAT | O_TRUNC, 0664);
             if (fd > 0) {
