@@ -849,20 +849,20 @@ size_t curlHeaderLine( void *ptr, size_t size, size_t nmemb, void *stream) {
                 else if (rc >= 400)
                     job->error_code = rc;
             }
-        } else if (job->redirected && !strncmp ((char *)ptr, "Location:", 9)) {
+        } else if (job->redirected && !strncasecmp ((char *)ptr, "location:", 9)) {
             String nuri ((char *)ptr+9);
             job->m_receiver->redirected (job, nuri.stripWhiteSpace ());
             job->redirected = false;
-        } else if (!strncmp ((char *)ptr, "Content-Length:", 15)) {
+        } else if (!strncasecmp ((char *)ptr, "content-length:", 15)) {
             job->content_length = strtol ((char *)ptr + 15, NULL, 10);
-        } else if (!strncmp ((char *)ptr, "Content-Type:", 13)) {
+        } else if (!strncasecmp ((char *)ptr, "content-type:", 13)) {
             job->content_type = String ((char *)ptr + 13).stripWhiteSpace ();
         }
     }
     return size * nmemb;
 }
 
-static 
+static
 size_t curlDataReceived (void *ptr, size_t size, size_t nmemb, void *stream) {
     CurlGetJob *job = (CurlGetJob *) stream;
     ByteArray data ((char *)ptr, size * nmemb);
