@@ -521,6 +521,7 @@ public:
     void writeEntry (const String & key, const String & val);
     void writeEntry (const String & key, int val);
     void writeEntry (const String & key, double val);
+    operator T & ();
 };
 
 class GConf {
@@ -534,6 +535,7 @@ public:
     void writeEntry (const String & key, const String & val);
     void writeEntry (const String & key, int val);
     void writeEntry (const String & key, double val);
+    operator GConfClient* ();
 };
 
 typedef ConfigTmpl <GConf> Config;
@@ -1551,35 +1553,39 @@ inline String MimeTypeTmpl <T>::findByURL (const URL & url) {
 //-----------------------------------------------------------------------------
 
 template <class T>
-String ConfigTmpl <T>::readEntry (const String & key, const String & def) {
+inline String ConfigTmpl <T>::readEntry (const String & key, const String & def) {
     return m_config.readEntry (key, def);
 }
 
 template <class T>
-int ConfigTmpl <T>::readNumEntry (const String & key, int def) {
+inline int ConfigTmpl <T>::readNumEntry (const String & key, int def) {
     return m_config.readEntry (key, def);
 }
 
 template <class T>
-double ConfigTmpl <T>::readNumEntry (const String & key, double def) {
+inline double ConfigTmpl <T>::readNumEntry (const String & key, double def) {
     return m_config.readEntry (key, def);
 }
 
 template <class T>
-void ConfigTmpl <T>::writeEntry (const String & key, const String & val) {
+inline void ConfigTmpl <T>::writeEntry (const String & key, const String & val) {
     m_config.writeEntry (key, val);
 }
 
 template <class T>
-void ConfigTmpl <T>::writeEntry (const String & key, int val) {
+inline void ConfigTmpl <T>::writeEntry (const String & key, int val) {
     m_config.writeEntry (key, val);
 }
 
 template <class T>
-void ConfigTmpl <T>::writeEntry (const String & key, double val) {
+inline void ConfigTmpl <T>::writeEntry (const String & key, double val) {
     m_config.writeEntry (key, val);
 }
 
+template <class T> inline ConfigTmpl <T>::operator T & () {
+    return m_config;
+}
+
 //-----------------------------------------------------------------------------
 
 KMPLAYER_NO_CDTOR_EXPORT inline Log::Log () {}
@@ -2101,6 +2107,10 @@ inline void GConf::writeEntry (const String & key, double val) {
     gconf_client_set_float (client, (const char *) key, val, 0L);
 }
 
+KMPLAYER_NO_EXPORT inline GConf::operator GConfClient * () {
+    return client;
+}
+
 //-----------------------------------------------------------------------------
 
 KMPLAYER_NO_CDTOR_EXPORT
