@@ -91,6 +91,14 @@ static void print (const char * format, ...) {
     fflush (stdout);
 }
 
+static void *nsAlloc (uint32 size) {
+    return g_malloc (size);
+}
+
+static void nsMemFree (void* ptr) {
+    g_free (ptr);
+}
+
 /*----------------%<---------------------------------------------------------*/
 
 static gint streamCompare (gconstpointer a, gconstpointer b) {
@@ -105,7 +113,7 @@ static void freeStream (StreamInfo *si) {
         g_free (si->mimetype);
     if (si->target)
         g_free (si->target);
-    free (si);
+    nsMemFree (si);
 }
 
 static gboolean requestStream (void * p) {
@@ -179,7 +187,7 @@ static int32_t writeStream (uint32_t stream, const char *buf, uint32_t count) {
 }
 
 static StreamInfo *addStream (const char *url, const char *mime, const char *target, void *notify_data, bool notify) {
-    StreamInfo *si = (StreamInfo *) malloc (sizeof (StreamInfo));
+    StreamInfo *si = (StreamInfo *) nsAlloc (sizeof (StreamInfo));
 
     memset (si, 0, sizeof (StreamInfo));
     si->url = g_strdup (url);
@@ -207,7 +215,7 @@ static void createJsName (JsObject * obj, char **name, uint32_t * len) {
         *len += slen + 1;
         createJsName (obj->parent, name, len);
     } else {
-        *name = (char *) malloc (*len + slen + 1);
+        *name = (char *) nsAlloc (*len + slen + 1);
         *(*name + *len + slen) = 0;
         *len = 0;
     }
@@ -223,15 +231,18 @@ static char *nsVariant2Str (const NPVariant *value) {
     char *str;
     switch (value->type) {
         case NPVariantType_String:
-            str = (char *) malloc (value->value.stringValue.utf8length + 3);
-            sprintf (str, "'%s'", value->value.stringValue.utf8characters);
+            str = (char *) nsAlloc (value->value.stringValue.utf8length + 3);
+            str[0] = str[value->value.stringValue.utf8length + 1] = '\'';
+            strncpy (str + 1, value->value.stringValue.utf8characters,
+                    value->value.stringValue.utf8length);
+            str[value->value.stringValue.utf8length + 2] = 0;
             break;
         case NPVariantType_Int32:
-            str = (char *) malloc (16);
+            str = (char *) nsAlloc (16);
             snprintf (str, 15, "%d", value->value.intValue);
             break;
         case NPVariantType_Double:
-            str = (char *) malloc (64);
+            str = (char *) nsAlloc (64);
             snprintf (str, 63, "%f", value->value.doubleValue);
             break;
         case NPVariantType_Bool:
@@ -247,7 +258,7 @@ static char *nsVariant2Str (const NPVariant *value) {
                 uint32_t vlen = 0;
                 createJsName (jv, &val, &vlen);
                 str = strdup (val);
-                free (val);
+                nsMemFree (val);
                 break;
             } /* else fall through */
         default:
@@ -342,14 +353,6 @@ static const char* nsUserAgent (NPP instance) {
     return "";*/
 }
 
-static void *nsAlloc (uint32 size) {
-    return malloc (size);
-}
-
-static void nsMemFree (void* ptr) {
-    free (ptr);
-}
-
 static uint32 nsMemFlush (uint32 size) {
     (void)size;
     print ("NPN_MemFlush\n");
@@ -521,20 +524,20 @@ static bool doEvaluate (NPP instance, NPObject * npobj, NPString * script,
     print ("NPN_Evaluate:");
 
     /* assign to a js variable */
-    this_var = (char *) malloc (64);
+    this_var = (char *) nsAlloc (64);
     sprintf (this_var, "this.__kmplayer__obj_%d", js_obj_counter);
 
-    jsscript = (char *) malloc (strlen (this_var) + script->utf8length + 3);
+    jsscript = (char *) nsAlloc (strlen (this_var) + script->utf8length + 3);
     sprintf (jsscript, "%s=%s;", this_var, script->utf8characters);
     this_var_string = browser_notify->evaluate (jsscript, browser_data);
-    free (jsscript);
+    nsMemFree (jsscript);
 
     if (this_var_string) {
         /* get type of js this_var */
-        jsscript = (char *) malloc (strlen (this_var) + 9);
+        jsscript = (char *) nsAlloc (strlen (this_var) + 9);
         sprintf (jsscript, "typeof %s;", this_var);
         this_var_type = browser_notify->evaluate (jsscript, browser_data);
-        free (jsscript);
+        nsMemFree (jsscript);
 
         if (this_var_type) {
             if (!strcasecmp (this_var_type, "undefined")) {
@@ -558,7 +561,7 @@ static bool doEvaluate (NPP instance, NPObject * npobj, NPString * script,
         print ("   => error\n");
         return false;
     }
-    free (this_var);
+    nsMemFree (this_var);
 
     return true;
 }
@@ -572,13 +575,13 @@ static bool nsEvaluate (NPP instance, NPObject * npobj, NPString * script,
 
     escaped = g_strescape (script->utf8characters, "");
     str.utf8length = strlen (escaped) + 9;
-    jsscript = (char *) malloc (str.utf8length);
+    jsscript = (char *) nsAlloc (str.utf8length);
     sprintf (jsscript, "eval(\"%s\")", escaped);
     str.utf8characters = jsscript;
 
     res = doEvaluate (instance, npobj, &str, result);
 
-    free (jsscript);
+    nsMemFree (jsscript);
     g_free (escaped);
 
     return res;
@@ -649,7 +652,7 @@ static bool nsPopPopupsEnabledState (NPP instance) {
 
 static NPObject * windowClassAllocate (NPP instance, NPClass *aClass) {
     /*print ("windowClassAllocate\n");*/
-    JsObject * jo = (JsObject *) malloc (sizeof (JsObject));
+    JsObject * jo = (JsObject *) nsAlloc (sizeof (JsObject));
     (void)instance;
     memset (jo, 0, sizeof (JsObject));
     jo->npobject._class = aClass;
@@ -662,12 +665,12 @@ static void windowClassDeallocate (NPObject *npobj) {
     if (jo->parent) {
         nsReleaseObject ((NPObject *) jo->parent);
     } else if (jo->name && !strncmp (jo->name, "this.__kmplayer__obj_", 21)) {
-        char *script = (char *) malloc (strlen (jo->name) + 7);
+        char *script = (char *) nsAlloc (strlen (jo->name) + 7);
         char *result;
         char *counter = strrchr (jo->name, '_');
         sprintf (script, "%s=null;", jo->name);
         result = browser_notify->evaluate (script, browser_data);
-        free (script);
+        nsMemFree (script);
         g_free (result);
         if (counter) {
             int c = strtol (counter +1, NULL, 10);
@@ -681,7 +684,7 @@ static void windowClassDeallocate (NPObject *npobj) {
         print ("WARNING deleting window object\n");
         js_window = NULL;
     }
-    free (npobj);
+    nsMemFree (npobj);
 }
 
 static void windowClassInvalidate (NPObject *npobj) {
@@ -715,11 +718,11 @@ static bool windowClassInvoke (NPObject *npobj, NPIdentifier method,
     print ("Invoke %s\n", id);
     createJsName (jo, (char **)&str.utf8characters, &str.utf8length);
     pos = snprintf (buf, sizeof (buf), "%s.%s(", str.utf8characters, id);
-    free ((char *) str.utf8characters);
+    nsMemFree ((char *) str.utf8characters);
     for (i = 0; i < arg_count; i++) {
         char *arg = nsVariant2Str (args + i);
         pos += snprintf (buf + pos, sizeof (buf) - pos, i ? ",%s" : "%s", arg);
-        free (arg);
+        nsMemFree (arg);
     }
     pos += snprintf (buf + pos, sizeof (buf) - pos, ")");
 
@@ -770,7 +773,7 @@ static bool windowClassGetProperty (NPObject *npobj, NPIdentifier property,
 
     res = doEvaluate (npp, npobj, &fullname, result);
 
-    free ((char *) fullname.utf8characters);
+    nsMemFree ((char *) fullname.utf8characters);
 
     return res;
 }
@@ -790,16 +793,16 @@ static bool windowClassSetProperty (NPObject *npobj, NPIdentifier property,
     createJsName (&jo, &var_name, &len);
 
     var_val = nsVariant2Str (value);
-    script = (char *) malloc (len + strlen (var_val) + 3);
+    script = (char *) nsAlloc (len + strlen (var_val) + 3);
     sprintf (script, "%s=%s;", var_name, var_val);
-    free (var_name);
-    free (var_val);
+    nsMemFree (var_name);
+    nsMemFree (var_val);
     print ("SetProperty %s\n", script);
 
     res = browser_notify->evaluate (script, browser_data);
     if (res)
         g_free (res);
-    free (script);
+    nsMemFree (script);
 
 
     return true;
@@ -820,7 +823,7 @@ void nppPluginShutdown (NPPluginLib *lib) {
         if (lib->npShutdown)
             lib->npShutdown();
         g_module_close (lib->module);
-        free (lib);
+        nsMemFree (lib);
     }
 }
 
@@ -837,7 +840,7 @@ NPPluginLib *nppPluginInit (const char *lib) {
         return NULL;
     }
 
-    plugin_lib = (NPPluginLib *)malloc (sizeof (NPPluginLib));
+    plugin_lib = (NPPluginLib *)nsAlloc (sizeof (NPPluginLib));
     plugin_lib->module = library;
 
     if (!g_module_symbol (library,
@@ -930,7 +933,7 @@ NPPluginLib *nppPluginInit (const char *lib) {
     return plugin_lib;
 
 bail_out:
-    free (plugin_lib);
+    nsMemFree (plugin_lib);
     return NULL;
 }
 
@@ -948,7 +951,7 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
     browser_data = ndata;
     browser_notify = notify;
 
-    npp = (NPP_t*)malloc (sizeof (NPP_t));
+    npp = (NPP_t*)nsAlloc (sizeof (NPP_t));
     memset (npp, 0, sizeof (NPP_t));
     for (i = 0; i < argc; i++) {
         print ("arg %s %s\n", argn[i], argv[i]);
@@ -963,7 +966,7 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
     np_err = np_funcs.newp (mime, npp, NP_EMBED, argc, argn, argv, saved_data);
     if (np_err != NPERR_NO_ERROR) {
         print ("NPP_New failure %d %p %p\n", np_err, np_funcs, np_funcs.newp);
-        free (npp);
+        nsMemFree (npp);
         return NULL;
     }
     if (np_funcs.getvalue) {
@@ -972,7 +975,7 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
         if (np_err != NPERR_NO_ERROR || !needs_xembed) {
             print ("NPP_GetValue NPPVpluginNeedsXEmbed failure %d\n", np_err);
             /*shutdownPlugin();*/
-            free (npp);
+            nsMemFree (npp);
             return NULL;
         }
         np_err = np_funcs.getvalue ((void*)npp,
@@ -1058,7 +1061,7 @@ void nppInstanceClose (void *pdata) {
     }
     if (npp) {
         np_funcs.destroy (npp, &saved_data);
-        free (npp);
+        nsMemFree (npp);
         npp = 0L;
     }
     top_w = 0;
