@@ -122,7 +122,7 @@ void ImageData::copyImage (Surface *s, int w, int h, cairo_surface_t *similar) {
     if (surface) {
         src_sf = surface;
     } else {
-        const GPixbuf &gpb = (const GPixbuf) *image;
+        const GPixbuf &gpb = (const GPixbuf &) *image;
         int channels;
         unsigned char *bits = pixbufBits (gpb.pixbuf (), channels);
         has_alpha = 4 == channels;
@@ -1700,7 +1700,7 @@ void ViewArea::setAudioVideoGeometry (const IRect &rect, unsigned int * bg_color
         debugLog() << "ViewArea::setAudioVideoGeometry " << x << "," << y << " "
             << w << "x" << h << endl;
         gdk_window_move_resize (video, x, y, w, h);
-        gdk_window_set_background (video, (GdkColor *)(GColor)color);
+        gdk_window_set_background (video, (GdkColor *) (GColor &) color);
         gdk_window_clear (video);
     }
 }
@@ -1902,10 +1902,13 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
     switch (event->xany.type) {
         case KeyPress:
         case KeyRelease: {
+            XKeyEvent keyevent = event->xkey;
+            if (a->fullscreen &&
+                    XKeycodeToKeysym (event->xany.display, keyevent.keycode, 0) == XK_F4)
+                return GDK_FILTER_CONTINUE; //GDK_FILTER_REMOVE;
             Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
             if (event->xany.window == v ||
                     isChildWindow(event->xany.display, v, event->xkey.window)) {
-                XKeyEvent keyevent = event->xkey;
                 keyevent.window =
                     GDK_DRAWABLE_XID (GDK_DRAWABLE (view_area->viewWidget ()->window));
                 XSendEvent (event->xany.display, keyevent.window, true,
@@ -1928,8 +1931,11 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
         case ButtonPress:
             if (a->fullscreen &&
                     event->xany.window == GDK_DRAWABLE_XID (GDK_DRAWABLE (view_area->viewWidget ()->window)) &&
-                    event->xbutton.x > 720 && event->xbutton.y < 60)
+                    event->xbutton.x > 720 && event->xbutton.y < 60) {
+                if (!view_area->controls_timer)
+                    updatePlayTree (a);
                 view_area->controlsVisible (true);
+            }
             break;
     }
     return GDK_FILTER_CONTINUE;
@@ -2088,7 +2094,7 @@ void cb_view_area_realized (GtkWidget *widget, Application * app) {
     gtk_widget_set_double_buffered (widget, false);
     if (widget == app->view_area_fullscreen) {
         Color c (0x101010);
-        gdk_window_set_background (widget->window, (GdkColor *)(GColor)c);
+        gdk_window_set_background (widget->window, (GdkColor *) (GColor &) c);
     } else {
         VIEWAREA(app)->setOutputWidget (app, widget);
     }
